package semfly.tests.agents;

import java.util.PriorityQueue;
import semfly.agents.ITPQOwner;
import semfly.agents.behaviours.DeleteMyself;
import semfly.onto.jade.IndexToken;
import jade.core.Agent;
import jade.content.lang.Codec;
import jade.content.onto.Ontology;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is used to test business logic of behaviours.
 */
public class Tester extends Agent implements ITPQOwner
{
    /**
	 * Tokens Priority Queue (TPQ).
	 */
	private PriorityQueue tokensPQ;
	
    /**
     * @see jade.core.Agent#setup()
	 */
	protected void setup() 
	{
	    tokensPQ = new PriorityQueue();
	    
		addBehaviour(new TestCoordinatorReceiverBL(this));
		addBehaviour(new TestDFAdapter());
		
		addBehaviour(new DeleteMyself());
	}
	
	public void registerLanguage(Codec codec)
	{
	    getContentManager().registerLanguage(codec);
	}
	
	public void registerOntology(Ontology ontology)
	{
	    getContentManager().registerOntology(ontology);
	}
	
	protected void takeDown()
	{
	    System.out.println("TESTER - take down");
	}
	
	public IndexToken poolIndexToken()
    {
        synchronized (tokensPQ)
        {
            return (IndexToken)tokensPQ.poll();
        }
    }
   
    public int getNumberOfTokens()
    {
        synchronized (tokensPQ)
        {
            return tokensPQ.size();
        }
    }
    
    public boolean hasIndexTokens()
    {
        synchronized (tokensPQ)
        {
            return tokensPQ.size() > 0;
        }
    }
    
	public void addIndexToken2TPQ(IndexToken token)
	{
	    assert token != null;
	    
	    synchronized (tokensPQ)
        {
	        tokensPQ.add(token);
        }
	}
	
	public void clearTPQ()
	{
	    tokensPQ.clear();
	}
}
