package semfly.tests.behaviours;

import junit.framework.TestCase;
import semfly.agents.behaviours.AirportsCodesLoaderBL;
import jade.core.Agent;
import semfly.dto.WebPageDocument;
import semfly.exceptions.WebSourceLoadException;
import semfly.exceptions.WebSourceParseException;


/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for testing AirportsCodesLoaderBL class.
 */
public class AirportsCodesLoaderTest extends TestCase
{
    /**
     * Tests object creation - agent (an input parameter for a constructor) is 
     * null.
     */
    public void testObjectCreation()
    {
        try
        {
            AirportsCodesLoaderBL airLoader = new AirportsCodesLoaderBL(null);
            fail("IllegalArgumentException expected");
        }
        catch (IllegalArgumentException ex){}
    }
    
    /**
     * Tests right (with a correct page URI) page loading.
     */
    public void testLoadRightPage()
    {
        AirportsCodesLoaderBL airLoader = 
            new AirportsCodesLoaderBL(new Agent());
        
        try
        {
            airLoader.loadAirportCodes();
        }
        catch (Exception ex)
        {
            assertTrue("Caught exception: " + ex.toString(), false);
        }
    }
    
    /**
     * Tests wrong (with an incorrect page URI) page loading.
     */
    public void testLoadWrongPage()
    {
        String baseURI = "baseURI";
        
        AirportsCodesLoaderBL airLoader = 
            new AirportsCodesLoaderBL(new Agent());
        
        try
        {
            airLoader.setCodeBaseURI(baseURI);
            airLoader.loadAirportCodes();
            fail("WebSourceLoadException expected");
        }
        catch (Exception ex) {}
    }
    
    /**
     * Tests extraction of airports codes from the right page (well formated).
     */
    public void testExtractCodesRightPage()
    {
        AirportsCodesLoaderBL airLoader = 
            new AirportsCodesLoaderBL(new Agent());
        
        try
        {
            WebPageDocument doc = airLoader.loadAirportCodes();
            airLoader.extractAirportCodes(doc.getWebDocument());
        }
        catch (Exception ex)
        {
            assertTrue("Caught exception: " + ex.toString(), false);
        }
    }
    
    /**
     * Tests extraction of airports codes from the wrong page (well formated).
     * Parsing exception should occure.
     */
    public void testExtractCodesWrongPage()
    {
        String baseURI = "http://www.wp.pl";
        String[] endURIs = new String[]{""};
        
        AirportsCodesLoaderBL airLoader = 
            new AirportsCodesLoaderBL(new Agent());
        
        try
        {
            airLoader.setCodeBaseURI(baseURI);
            airLoader.setCodesEndURI(endURIs);
            WebPageDocument doc = airLoader.loadAirportCodes();
            airLoader.extractAirportCodes(doc.getWebDocument());
            fail("WebSourceParseException expected");
        }
        catch (WebSourceParseException ex) { }
        catch (WebSourceLoadException ex)
        {
            assertTrue("Caught exception: " + ex.toString(), false);
        }
    }
    
    /**
     * Tests extraction of airports codes from the null page.
     */
    public void testExtractCodesNullPage()
    {
        AirportsCodesLoaderBL airLoader = 
            new AirportsCodesLoaderBL(new Agent());
        
        try
        {
            airLoader.extractAirportCodes(null);
            fail("IllegalArgumentException expected");
        }
        catch (Exception ex) { }
    }
}
