package semfly.tests.behaviours;

import semfly.agents.behaviours.AirportsInfoLoaderBL;
import junit.framework.TestCase;
import jade.core.Agent;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for testing AirportsInfoLoaderBL class.
 */
public class AirportsInfoLoaderTest extends TestCase
{
    /**
     * Tests object creation. Uses different input parameters:
     * Agent = null/new Agent() and Airport Codes = null/new String[]{""}
     */
    public void testObjectCreation()
    {
        AirportsInfoLoaderBL airLoader;
        try
        {
            airLoader = new AirportsInfoLoaderBL(null, null);
            fail("IllegalArgumentException expected");
        }
        catch (IllegalArgumentException ex){}
        
        try
        {
            airLoader = new AirportsInfoLoaderBL(null, new String[]{""});
            fail("IllegalArgumentException expected");
        }
        catch (IllegalArgumentException ex){}
        
        try
        {
            airLoader = new AirportsInfoLoaderBL(new Agent(), null);
            fail("IllegalArgumentException expected");
        }
        catch (IllegalArgumentException ex){}
        
        try
        {
            airLoader = new AirportsInfoLoaderBL(new Agent(), new String[]{""});
        }
        catch (IllegalArgumentException ex)
        {
            assertTrue("Caught exception: " + ex, false);
        }
    }
    
    /**
     * Tests right (with a correct page URI) page loading.
     */
    public void testLoadRightPage()
    {
        AirportsInfoLoaderBL airLoader = 
            new AirportsInfoLoaderBL(new Agent(), new String[]{""});
        
        try
        {
            airLoader.loadResources();
        }
        catch (Exception ex)
        {
            assertTrue("Caught exception: " + ex.toString(), false);
        }
    }
    
    /**
     * Tests wrong (with an incorrect page URI) page loading.
     */
    public void testLoadWrongPage()
    {
        String uri = "URI";
        
        AirportsInfoLoaderBL airLoader = 
            new AirportsInfoLoaderBL(new Agent(), new String[]{"ADK"});
        
        try
        {
            airLoader.setWebSiteURI(uri);
            airLoader.loadResources();
            fail("Exception expected");
        }
        catch (Exception ex) {}
    }
    
    /**
     * Tests page loading having an empty array of airports codes.
     */
    public void testLoadPageEmptyCodes()
    {
        AirportsInfoLoaderBL airLoader = 
            new AirportsInfoLoaderBL(new Agent(), new String[0]);
        
        try
        {
            airLoader.loadResources();
        }
        catch (Exception ex) 
        {
            assertTrue("Caught exception: " + ex.toString(), false);
        }
    }
    
    /**
     * Tests page loading having an empty array of airports codes.
     */
    public void testLoadPageRandomCodes()
    {
        AirportsInfoLoaderBL airLoader = 
            new AirportsInfoLoaderBL(new Agent(), new String[]{"!@#", "AC1"});
        
        try
        {
            airLoader.loadResources();
        }
        catch (Exception ex) 
        {
            assertTrue("Caught exception: " + ex.toString(), false);
        }
    }
}
