package semfly.tests.behaviours;

import jade.core.Agent;
import semfly.agents.behaviours.AirportsInfoLoaderBL;
import semfly.agents.behaviours.AirportsInfoProcessorBL;
import semfly.net.WebSiteLoader;
import junit.framework.TestCase;
import semfly.exceptions.WebSourceParseException;
import org.apache.commons.httpclient.methods.PostMethod;
import org.w3c.dom.Document;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for testing AirportsInfoProcessorBL class.
 */
public class AirportsInfoProcessorTest extends TestCase
{
    /**
     * Tests object creation. Uses different input parameters:
     * Agent = null/new Agent() and Airport Codes = null/new String[]{""}
     */
    public void testObjectCreation()
    {
        AirportsInfoProcessorBL airProcessor;
        try
        {
            airProcessor = new AirportsInfoProcessorBL(null, null);
            fail("IllegalArgumentException expected");
        }
        catch (IllegalArgumentException ex){}
        
        try
        {
            airProcessor = 
                new AirportsInfoProcessorBL(new Agent(), new Document[0]);
        }
        catch (IllegalArgumentException ex)
        {
            assertTrue("Caught exception: " + ex, false);
        }
    }
    
    /**
     * Tests processing of an array of correct documents (web pages) 
     * describing airports details.
     */
    public void testProcessRightAirportsDeatails()
    {
        AirportsInfoLoaderBL airLoader = 
            new AirportsInfoLoaderBL(new Agent(), 
                    new String[]{"ATU", "ANC", "MRI", "BET", "BRW"});
        try
        {
            Document[] airports = airLoader.loadResources();
            AirportsInfoProcessorBL airProcessor = 
                new AirportsInfoProcessorBL(new Agent(), airports);
            airProcessor.processResource();
        }
        catch (Exception ex)
        {
            assertTrue("Caught exception: " + ex.toString(), false);
        }
    }
    
    /**
     * Test processing of an invalidate page with airport details. Uses page
     * that doesn't include any airport related info.
     */
    public void testProcessInvalidAirportDetails()
    {
        WebSiteLoader webLoader = new WebSiteLoader();
		Document doc = null;
		
		PostMethod httpMethod = new PostMethod("http://www.wp.pl");
		
		try
		{
			doc = webLoader.loadWebSiteHTML(httpMethod);
			AirportsInfoProcessorBL airProcessor = 
                new AirportsInfoProcessorBL(new Agent(), new Document[]{doc});
            airProcessor.processResource();
            fail("WebSourceParseException expected");
		}
		catch (WebSourceParseException ex) {}
		catch (Exception ex) 
		{
		    assertTrue("Another exception caught: " + ex, false);
		}
    }
}
