package semfly.tests.behaviours;

import semfly.agents.behaviours.WrapperSenderBL;
import junit.awtui.TestRunner;
import junit.framework.TestCase;
import jade.lang.acl.ACLMessage;

import java.util.Random;
import java.util.Vector;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for testing WrapperSenderBL class.
 */
public class WrapperSenderTest extends TestCase
{
    /**
     * Test data.
     */
    private AgentsInfoTestData agentsInfoTD;
    
    /**
     * Runs tests.
     */
    public static void main(String[] args)
    {
        TestRunner.run(WrapperSenderTest.class);
    }
    
    /**
     * Creates test data.
     */
    protected void setUp()
    {
        agentsInfoTD = new AgentsInfoTestData();
    }
    
    /**
     * Tests proposals evaluation by using empty vectors.
     */
    public void testEvaluateProposals_EmptyVectors()
    {
        try
        {
            WrapperSenderBL senderBL = new WrapperSenderBL();
            senderBL.evaluateProposals(new Vector(), new Vector());
        }
        catch (Exception ex)
        {
            assertTrue("Caught exception: " + ex.toString(), false);
        }
    }
    
    /**
     * Tests proposals evaluation by using desceding sorted list of propositions.
     */
    public void testSelectBestProp_SortedDESC()
    {
        createPropositionsSortedDESC();
        
        WrapperSenderBL senderBL = new WrapperSenderBL();
        ACLMessage bestProp = senderBL.selectBestProposition(
                				agentsInfoTD.getAllPropositionsAsVector());
        
        checkBestProposition(bestProp);
    }
    
    /**
     * Tests proposals evaluation by using ascending sorted list of propositions.
     */
    public void testSelectBestProp_SortedASC()
    {
        createPropositionsSortedASC();
        
        WrapperSenderBL senderBL = new WrapperSenderBL();
        ACLMessage bestProp = senderBL.selectBestProposition(
                				agentsInfoTD.getAllPropositionsAsVector());
        
        checkBestProposition(bestProp);
    }
    
    /**
     * Tests proposals evaluation by using random list of propositions.
     */
    public void testSelectBestProp_Random()
    {
        createPropositionsRandom();
        
        WrapperSenderBL senderBL = new WrapperSenderBL();
        ACLMessage bestProp = senderBL.selectBestProposition(
                				agentsInfoTD.getAllPropositionsAsVector());
        
        checkBestProposition(bestProp);
    }
    
    private void checkBestProposition(ACLMessage bestProposition)
    {
        WrapperSenderBL senderBL = new WrapperSenderBL();
        
        assertEquals("bestProposition != bestProposition",
                senderBL.extractNumberOfTokens(agentsInfoTD.getBestProposition()),
                senderBL.extractNumberOfTokens(bestProposition));
    }
    
    private void createPropositionsSortedDESC()
    {
        int cnt = 10;
        
        ACLMessage[] allPropositions = new ACLMessage[cnt];
        ACLMessage msg;
        for (int i = 0; i < cnt; i++)
        {
            msg = new ACLMessage(ACLMessage.PROPOSE);
            msg.setContent((new Integer(cnt - i)).toString());
            allPropositions[i] = msg;
        }
        
        agentsInfoTD.setAllPropositions(allPropositions);
        agentsInfoTD.setBestProposition(allPropositions[cnt - 1]);
    }
    
    private void createPropositionsSortedASC()
    {
        int cnt = 10;
        
        ACLMessage[] allPropositions = new ACLMessage[cnt];
        ACLMessage msg;
        for (int i = 0; i < cnt; i++)
        {
            msg = new ACLMessage(ACLMessage.PROPOSE);
            msg.setContent((new Integer(i)).toString());
            allPropositions[i] = msg;
        }
        
        agentsInfoTD.setAllPropositions(allPropositions);
        agentsInfoTD.setBestProposition(allPropositions[0]);
    }
    
    private void createPropositionsRandom()
    {
        int cnt = 10;
        
        Random rnd = new Random();
        ACLMessage[] allPropositions = new ACLMessage[cnt];
        ACLMessage bestProp, msg;
        
        int minVal = rnd.nextInt(), tmpVal;
        bestProp = allPropositions[0] = new ACLMessage(ACLMessage.PROPOSE);
        bestProp.setContent("" + minVal);
        
        for (int i = 1; i < cnt; i++)
        {
            msg = new ACLMessage(ACLMessage.PROPOSE);
            tmpVal = rnd.nextInt();
            msg.setContent("" + tmpVal);
            allPropositions[i] = msg;
            
            if (minVal > tmpVal)
            {
                bestProp = msg;
                minVal = tmpVal;
            }
        }
        
        agentsInfoTD.setAllPropositions(allPropositions);
        agentsInfoTD.setBestProposition(bestProp);
    }
    
    /**
     * This class represents test data.
     */
    private class AgentsInfoTestData
    {
        ACLMessage[] allPropositions;
        ACLMessage bestProposition;
        
        
        public ACLMessage[] getAllPropositions()
        {
            return allPropositions;
        }
        
        public Vector getAllPropositionsAsVector()
        {
            Vector vector = new Vector();
            for (int i = 0; i < allPropositions.length; i++)
                vector.add(allPropositions[i]);
            
            return vector;
        }
        
        public void setAllPropositions(ACLMessage[] allPropositions)
        {
            this.allPropositions = allPropositions;
        }
        
        public ACLMessage getBestProposition()
        {
            return bestProposition;
        }
        
        public void setBestProposition(ACLMessage bestProposition)
        {
            this.bestProposition = bestProposition;
        }
    }
}
