package semfly.tests.net;

import org.apache.commons.httpclient.methods.GetMethod;
import org.apache.commons.httpclient.methods.PostMethod;
import semfly.net.WebSiteLoader;
import junit.awtui.TestRunner;
import junit.framework.TestCase;

/**
 * @author Szymon Pisarek (szymekpi@o2.pl)
 *
 * This class is responsible for testing WebSiteLoader class.
 */
public class WebSiteLoaderTest extends TestCase
{
    public static void main(String[] args)
    {
        TestRunner.run(WebSiteLoaderTest.class);
    }
    
    /**
     * Tests page loading with valid server address by means of POST method.
     */
    public void testLoadValidServerPOST()
    {
        String pageURI = "http://www.wp.pl";
        
        PostMethod method = new PostMethod(pageURI);
        WebSiteLoader webLoader = new WebSiteLoader();
        
        try
        {
            webLoader.loadWebSite(method);
        }
        catch (Exception ex)
        {
            assertTrue("Caught exception: " + ex, false);
        }
    }
    
    /**
     * Tests page loading with valid server address by means of GET method.
     */
    public void testLoadValidServerGET()
    {
        String pageURI = "http://www.wp.pl";
        
        GetMethod method = new GetMethod(pageURI);
        WebSiteLoader webLoader = new WebSiteLoader();
        
        try
        {
            webLoader.loadWebSite(method);
        }
        catch (Exception ex)
        {
            assertTrue("Caught exception: " + ex, false);
        }
    }
    
    /**
     * Tests page loading with invalid server address by means of POST method.
     */
    public void testLoadInvalidServerPOST()
    {
        String pageURI = "invalidate server address";
        
        try
        {
            PostMethod method = new PostMethod(pageURI);
            WebSiteLoader webLoader = new WebSiteLoader();
            webLoader.loadWebSite(method);
            fail("Exception expected");
        }
        catch (Exception ex) {}
    }
    
    /**
     * Tests page loading with invalid server address by means of GET method.
     */
    public void testLoadInvalidServerGET()
    {
        String pageURI = "invalidate server address";
        
        try
        {
            GetMethod method = new GetMethod(pageURI);
            WebSiteLoader webLoader = new WebSiteLoader();
            webLoader.loadWebSite(method);
            fail("Exception expected");
        }
        catch (Exception ex) {}
    }
    
    /**
     * Tests page loading with null server address (null HttpMethod).
     */
    public void testLoadNullMethod()
    {
        try
        {
            WebSiteLoader webLoader = new WebSiteLoader();
            webLoader.loadWebSite(null);
            fail("Exception expected");
        }
        catch (Exception ex) {}
    }
}
